@@ -1,5 +1,6 @@
 """
-Classes and functions to read the CHAOS model.
+Classes and functions to read the CHAOS model and other geomagnetic field
+models.
 
 .. autosummary::
     :toctree: classes
@@ -48,7 +49,7 @@ class Base(object):
 
         # ensure breaks is None or has 2 elements
         if breaks is not None:
-            breaks = np.asarray(breaks, dtype=np.float)
+            breaks = np.asarray(breaks, dtype=float)
             if breaks.size == 1:
                 breaks = np.append(breaks, breaks)
 
@@ -62,7 +63,7 @@ class Base(object):
             self.dim = None
 
         else:
-            coeffs = np.asarray(coeffs, dtype=np.float)
+            coeffs = np.asarray(coeffs, dtype=float)
 
             if order is None:
                 self.order = coeffs.shape[0]
@@ -81,13 +82,12 @@ class Base(object):
         Parameters
         ----------
         time : ndarray, shape (...) or float
-            Array containing the time in modified Julian dates.
+            Array containing the time in modified Julian date.
         dim : int, positive, optional
             Truncation value of the number of coefficients (no truncation by
             default).
         deriv : int, positive, optional
-            Derivative in time (None defaults to 0). For secular variation,
-            choose ``deriv=1``.
+            Derivative in time (None defaults to 0).
         extrapolate : {'linear', 'quadratic', 'cubic', 'spline', 'constant', \
 'off'} or int, optional
             Extrapolate to times outside of the piecewise polynomial bounds.
@@ -155,7 +155,7 @@ class Base(object):
                 try:
                     key = min(dkey[extrapolate], self.order)
                 except KeyError:
-                    string = '", "'.join([*dkey.keys()])
+                    string = '", "'.join(list(dkey.keys()))
                     raise ValueError(
                         f'Unknown extrapolation method "{extrapolate}". Use '
                         f'one of {{"{string}"}}.')
@@ -165,7 +165,7 @@ class Base(object):
 
             message = 'no' if extrapolate == 'off' else extrapolate
             warnings.warn("Requested coefficients are "
-                          "outside of the modelled period from "
+                          "outside of the model period from "
                           f"{start} to {end}. Doing {message} extrapolation.")
 
             if key > 0:
@@ -205,9 +205,9 @@ class Base(object):
 
         pp = dict(
             form='pp',
-            order=self.order,
-            pieces=self.pieces,
-            dim=dim,
+            order=float(self.order),
+            pieces=float(self.pieces),
+            dim=float(dim),
             breaks=self.breaks.reshape((1, -1)),  # ensure 2d
             coefs=coefs)
 
@@ -216,37 +216,39 @@ class Base(object):
 
 class BaseModel(Base):
     """
-    Class for time-dependent (piecewise polynomial) model.
+    Class for piecewise polynomial spherical harmonic models.
 
     Parameters
     ----------
     name : str
         User specified name of the model.
     breaks : ndarray, shape (m+1,)
-        Break points for piecewise-polynomial representation of the
-        time-dependent internal field in modified Julian date format.
+        Break points (`m` pieces plus one) for the piecewise polynomial
+        representation of the field model in modified Julian date format.
+        If a single break point is given, it is appended to itself to have two
+        points defining the model interval (single piece).
     order : int, positive
-        Order `k` of polynomial pieces (e.g. 4 = cubic) of the time-dependent
-        field.
+        Order `k` of the polynomial pieces (e.g. 1 = constant, 4 = cubic).
     coeffs : ndarray, shape (`k`, `m`, ``nmax`` * (``nmax`` + 2))
-        Coefficients of the time-dependent field.
+        Coefficients of the piecewise polynomial representation of the
+        field model.
     source : {'internal', 'external'}
         Internal or external source (defaults to ``'internal'``)
     meta : dict, optional
-        Dictionary containing additional information about the model.
+        Dictionary containing additional information about the model if
+        available.
 
     Attributes
     ----------
     breaks : ndarray, shape (m+1,)
-        Break points for piecewise-polynomial representation of the
-        magnetic field in modified Julian date format.
+        Break points (`m` pieces plus one) for the piecewise polynomial
+        representation of the field model in modified Julian date format.
     pieces : int, positive
         Number `m` of intervals given by break points in ``breaks``.
     order : int, positive
-        Order `k` of polynomial pieces (e.g. 4 = cubic) of the time-dependent
-        field.
+        Order `k` of the polynomial pieces (e.g. 1 = constant, 4 = cubic).
     nmax : int, positive
-        Maximum spherical harmonic degree of the time-dependent field.
+        Maximum spherical harmonic degree of the field model.
     dim : int, ``nmax`` * (``nmax`` + 2)
         Dimension of the model.
     coeffs : ndarray, shape (`k`, `m`, ``nmax`` * (``nmax`` + 2))
@@ -254,15 +256,15 @@ class BaseModel(Base):
     source : {'internal', 'external'}
         Internal or external source (defaults to ``'internal'``)
     meta : dict, optional
-        Dictionary containing additional information about the model.
+        Dictionary containing additional information about the model if
+        available.
 
     """
 
     def __init__(self, name, breaks=None, order=None, coeffs=None,
                  source=None, meta=None):
         """
-        Initialize time-dependent spherical harmonic model as a piecewise
-        polynomial.
+        Initialize spherical harmonic model as a piecewise polynomial.
 
         """
 
@@ -285,10 +287,10 @@ class BaseModel(Base):
         time : ndarray, shape (...) or float
             Array containing the time in modified Julian dates.
         nmax : int, positive, optional
-            Maximum degree harmonic expansion (default is given by the model
-            coefficients, but can also be smaller, if specified).
+            Maximum degree of the harmonic expansion (default is given by the
+            model coefficients, but can also be smaller, if specified).
         deriv : int, positive, optional
-            Derivative in time (None defaults to 0). For secular variation,
+            Derivative in time (defaults to 0). For secular variation,
             choose ``deriv=1``.
         extrapolate : {'linear', 'quadratic', 'cubic', 'spline', 'constant', \
 'off'} or int, optional
@@ -319,7 +321,7 @@ class BaseModel(Base):
 
         """
 
-        dim = None if nmax is None else nmax*(nmax+2)
+        dim = None if nmax is None else int(nmax*(nmax+2))
         coeffs = super().synth_coeffs(time, dim=dim, deriv=deriv,
                                       extrapolate=extrapolate)
 
@@ -328,23 +330,23 @@ class BaseModel(Base):
     def synth_values(self, time, radius, theta, phi, *, nmax=None,
                      deriv=None, grid=None, extrapolate=None):
         """
-        Compute magnetic components of the time-dependent field.
+        Compute magnetic components from the field model.
 
         Parameters
         ----------
         time : ndarray, shape (...) or float
-            Array containing the time in modified Julian dates.
+            Array containing the time in modified Julian date.
         radius : ndarray, shape (...) or float
-            Radius of station in kilometers.
+            Radius in kilometers.
         theta : ndarray, shape (...) or float
-            Colatitude in degrees :math:`[0^\\circ, 180^\\circ]`.
+            Colatitude in degrees.
         phi : ndarray, shape (...) or float
             Longitude in degrees.
         nmax : int, positive, optional
-            Maximum degree harmonic expansion (default is given by the model
-            coefficients, but can also be smaller, if specified).
+            Maximum degree of the harmonic expansion (default is given by the
+            model coefficients, but can also be smaller, if specified).
         deriv : int, positive, optional
-            Derivative in time (None defaults to 0). For secular variation,
+            Derivative in time (defaults to 0). For secular variation,
             choose ``deriv=1``.
         grid : bool, optional
             If ``True``, field components are computed on a regular grid.
@@ -361,12 +363,17 @@ class BaseModel(Base):
         B_radius, B_theta, B_phi : ndarray, shape (...)
             Radial, colatitude and azimuthal field components.
 
-        See Also
-        --------
-        CHAOS.synth_values_tdep
-
         """
 
+        if nmax is None:
+            nmax = self.nmax
+        elif nmax > self.nmax:
+            warnings.warn(
+                f'Supplied nmax = {nmax} is incompatible with number of '
+                f'coefficients. Using nmax = {self.nmax} instead.'
+            )
+            nmax = self.nmax
+
         coeffs = self.synth_coeffs(time, nmax=nmax, deriv=deriv,
                                    extrapolate=extrapolate)
 
@@ -375,26 +382,27 @@ class BaseModel(Base):
 
     def power_spectrum(self, time, radius=None, **kwargs):
         """
-        Compute the powerspectrum.
+        Compute the spatial power spectrum.
 
         Parameters
         ----------
         time : ndarray, shape (...)
             Time in modified Julian date.
-        radius : float
+        radius : float, optional
             Radius in kilometers (defaults to mean Earth's surface defined in
             ``basicConfig['r_surf']``).
 
         Returns
         -------
         R_n : ndarray, shape (..., ``nmax``)
-            Power spectrum of spherical harmonics up to degree ``nmax``.
+            Spatial power spectrum of the spherical harmonic expansion up to
+            degree ``nmax``.
 
         Other Parameters
         ----------------
         nmax : int, positive, optional
-            Maximum degree harmonic expansion (default is given by the model
-            coefficients, but can also be smaller, if specified).
+            Maximum degree of the harmonic expansion (default is given by the
+            model coefficients, but can also be smaller, if specified).
         deriv : int, positive, optional
             Derivative in time (default is 0). For secular variation, choose
             ``deriv=1``.
@@ -415,7 +423,7 @@ class BaseModel(Base):
 
     def plot_power_spectrum(self, time, **kwargs):
         """
-        Plot the power spectrum.
+        Plot the spatial power spectrum.
 
         Parameters
         ----------
@@ -431,7 +439,7 @@ class BaseModel(Base):
         defaults = dict(radius=None,
                         deriv=0,
                         nmax=self.nmax,
-                        titles='power spectrum')
+                        titles='spatial power spectrum')
 
         kwargs = defaultkeys(defaults, kwargs)
 
@@ -467,8 +475,8 @@ class BaseModel(Base):
         Other Parameters
         ----------------
         nmax : int, positive, optional
-            Maximum degree harmonic expansion (default is given by the model
-            coefficients, but can also be smaller, if specified).
+            Maximum degree of the harmonic expansion (default is given by the
+            model coefficients, but can also be smaller, if specified).
         deriv : int, positive, optional
             Derivative in time (default is 0). For secular variation, choose
             ``deriv=1``.
@@ -506,7 +514,7 @@ class BaseModel(Base):
                     nmax, self.nmax))
             nmax = self.nmax
 
-        time = np.array(time, dtype=np.float)
+        time = np.array(time, dtype=float)
         theta = np.linspace(1, 179, num=320)
         phi = np.linspace(-180, 180, num=721)
 
@@ -540,8 +548,8 @@ class BaseModel(Base):
         Other Parameters
         ----------------
         nmax : int, positive, optional
-            Maximum degree harmonic expansion (default is given by the model
-            coefficients, but can also be smaller, if specified).
+            Maximum degree of the harmonic expansion (default is given by the
+            model coefficients, but can also be smaller, if specified).
         deriv : int, positive, optional
             Derivative in time (default is 0). For secular variation, choose
             ``deriv=1``.
@@ -611,25 +619,91 @@ class BaseModel(Base):
 
         """
 
-        degree = order - 1
-        breaks = np.unique(knots)  # remove endpoint multiplicity
-        pieces = breaks.size - 1  # number of polynomial pieces
-        dim = coeffs.shape[-1]  # dimension = number of Gauss coefficients
-
-        coeffs_pp = np.zeros((order, pieces, dim))
-
-        # have to do it manually for each dimension, scipy only univariate
-        for d in range(dim):
-
-            bs = sip.BSpline(knots, coeffs[:, d], degree)
-            pp = sip.PPoly.from_spline(bs, extrapolate=False)
-
-            # remove multiple pp-coefficients at endpoints
-            coeffs_pp[:, :, d] = pp.c[:, degree:(degree+pieces)]
+        coeffs_pp, breaks = mu.pp_from_bspline(coeffs, knots, order)
 
         return cls(name, breaks=breaks, order=order, coeffs=coeffs_pp,
                    source=source, meta=meta)
 
+    @classmethod
+    def from_shc(cls, filepath, *, name=None, leap_year=None,
+                 source=None, meta=None):
+        """
+        Return BaseModel instance by loading a model from an shc-file.
+
+        Parameters
+        ----------
+        filepath : str
+            Path to shc-file.
+        name : str, optional
+            User defined name of the model. Defaults to the filename without
+            the file extension.
+        leap_year : {True, False}, optional
+            Take leap year in time conversion into account (default).
+            Otherwise, use conversion factor of 365.25 days per year.
+        source : {'internal', 'external'}
+            Internal or external source (defaults to ``'internal'``)
+        meta : dict, optional
+            Dictionary containing additional information about the model.
+
+        Returns
+        -------
+        model : :class:`BaseModel`
+            Class :class:`BaseModel` instance.
+
+        """
+
+        if name is None:
+            # get name without extension
+            name = os.path.splitext(os.path.basename(filepath))[0]
+
+        source = 'internal' if source is None else source
+        leap_year = True if leap_year is None else leap_year
+
+        time, coeffs, params = du.load_shcfile(filepath, leap_year=leap_year)
+
+        nmin = params['nmin']
+        nmax = params['nmax']
+        order = params['order']
+        step = order - 1  # actually params['step'], but not reliable
+
+        # make single piece by setting both ends equal
+        if time.size == 1:
+            breaks = np.append(time, time)
+        else:
+            breaks = time[::step]
+
+        # need to pad coefficients
+        if nmin > 1:
+            coeffs_pad = np.zeros((nmax*(nmax + 2),) + coeffs.shape[1:])
+            coeffs_pad[int(nmin**2 - 1):, ...] = coeffs
+        else:
+            coeffs_pad = coeffs
+
+        pieces = breaks.size - 1  # number of polynomial pieces
+
+        if (pieces == 1) and (order == 1):  # static field in single bin
+
+            coeffs_out = coeffs_pad.reshape((1, 1, -1))
+
+            return cls(name, breaks=breaks, order=order, coeffs=coeffs_out,
+                       source=source, meta=meta)
+
+        else:  # model must be time-dependent (incl. piecewise constant)
+
+            # there may be extra sites to extend the model interval,
+            # but it is not clear how to handle this in a unique way.
+            # I therefore just discard these extrapolation sites
+            end = (time.size // step) * step
+
+            knots = mu.augment_breaks(breaks, order)
+            spl = sip.make_lsq_spline(time[:end], coeffs_pad[:, :end].T,
+                                      knots, order - 1)
+            coeffs_out = spl.c.copy()
+
+            # convert B-spline basis to PPoly
+            return cls.from_bspline(name, knots=knots, coeffs=coeffs_out,
+                                    order=order, source=source, meta=meta)
+
 
 class CHAOS(object):
     """
@@ -638,7 +712,7 @@ class CHAOS(object):
     Parameters
     ----------
     breaks : ndarray, shape (m+1,)
-        Break points for piecewise-polynomial representation of the
+        Break points for piecewise polynomial representation of the
         time-dependent internal (i.e. large-scale core) field in modified
         Julian date format.
     order : int, positive
@@ -717,12 +791,22 @@ class CHAOS(object):
 
     """
 
-    def __init__(self, breaks, order=None, *,
-                 coeffs_tdep=None, coeffs_static=None,
-                 coeffs_sm=None, coeffs_gsm=None,
-                 breaks_delta=None, coeffs_delta=None,
-                 breaks_euler=None, coeffs_euler=None,
-                 name=None, meta=None):
+    def __init__(
+        self,
+        breaks,
+        order=None,
+        *,
+        coeffs_tdep=None,
+        coeffs_static=None,
+        coeffs_sm=None,
+        coeffs_gsm=None,
+        breaks_delta=None,
+        coeffs_delta=None,
+        breaks_euler=None,
+        coeffs_euler=None,
+        name=None,
+        meta=None
+    ):
         """
         Initialize the CHAOS model.
 
@@ -769,10 +853,15 @@ class CHAOS(object):
                 except KeyError:
                     Euler_prerotation = None
 
-                model = Base(satellite, order=1,
-                             breaks=breaks_euler[satellite],
-                             coeffs=coeffs_euler[satellite],
-                             meta={'Euler_prerotation': Euler_prerotation})
+                model = Base(
+                    satellite,
+                    order=1,
+                    breaks=breaks_euler[satellite],
+                    coeffs=coeffs_euler[satellite],
+                    meta={
+                        'Euler_prerotation': Euler_prerotation
+                    }
+                )
                 self.model_euler[satellite] = model
 
         # give the model a name: CHAOS-x.x or user input
@@ -828,10 +917,10 @@ str, {'internal', 'external'}
 
         """
 
-        time = np.array(time, dtype=float)
-        radius = np.array(radius, dtype=float)
-        theta = np.array(theta, dtype=float)
-        phi = np.array(phi, dtype=float)
+        time = np.asarray(time, dtype=float)
+        radius = np.asarray(radius, dtype=float)
+        theta = np.asarray(theta, dtype=float)
+        phi = np.asarray(phi, dtype=float)
 
         if source_list is None:
             source_list = ['tdep', 'static', 'gsm', 'sm']
@@ -942,8 +1031,7 @@ str, {'internal', 'external'}
         Print model version and initialization timestamp.
         """
 
-        string = (f"This is {self.name} (v{basicConfig['params.version']})"
-                  f" initialized on {self.timestamp} UTC.")
+        string = (f"This is {self.name} initialized on {self.timestamp} UTC.")
 
         return string
 
@@ -972,7 +1060,7 @@ str, {'internal', 'external'}
         --------
         >>> import chaosmagpy as cp
         >>> model = cp.CHAOS.from_mat('CHAOS-6-x7.mat')
-        >>> time = np.linspace(0., 10., num=2)
+        >>> time = np.array([0., 10.])
 
         >>> model.synth_coeffs_tdep(time, nmax=1)  # dipole coefficients
         array([[-29614.72797782,  -1728.47079907,   5185.50518939],
@@ -1027,7 +1115,7 @@ str, {'internal', 'external'}
         --------
         >>> import chaosmagpy as cp
         >>> model = cp.CHAOS.from_mat('CHAOS-6-x7.mat')
-        >>> time = np.linspace(0., 10., num=2)
+        >>> time = np.array([0., 10.])
 
         Compute magnetic field components at specific location.
 
@@ -1266,7 +1354,7 @@ str, {'internal', 'external'}
             source = 'external'
 
         # ensure ndarray input
-        time = np.array(time, dtype=np.float)
+        time = np.asarray(time, dtype=float)
 
         # use static part to define modelled period
         start = self.model_static.breaks[0]
@@ -1274,7 +1362,7 @@ str, {'internal', 'external'}
 
         if np.amin(time) < start or np.amax(time) > end:
             warnings.warn("Requested coefficients are "
-                          "outside of the modelled period from "
+                          "outside of the model period from "
                           f"{start} to {end}. Doing linear extrapolation in "
                           "GSM reference frame.")
 
@@ -1352,7 +1440,7 @@ str, {'internal', 'external'}
         --------
         >>> import chaosmagpy as cp
         >>> model = cp.CHAOS.from_mat('CHAOS-6-x7.mat')
-        >>> time = np.linspace(0., 10., num=2)
+        >>> time = np.array([0., 10.])
         >>> Br, Bt, Bp = model.synth_values_gsm(time, 6371.2, 45., 0.)
         >>> Br
         array([-8.18751916, -8.25661729])
@@ -1388,7 +1476,7 @@ str, {'internal', 'external'}
 
         return B_radius, B_theta, B_phi
 
-    def synth_coeffs_sm(self, time, *, nmax=None, source=None):
+    def synth_coeffs_sm(self, time, *, nmax=None, source=None, rc=None):
         """
         Compute the external SM field from the CHAOS model.
 
@@ -1401,6 +1489,15 @@ str, {'internal', 'external'}
             coefficients, but can also be smaller, if specified).
         source : {'external', 'internal'}, optional
             Choose source either external or internal (default is 'external').
+        rc : ndarray, shape (...), optional
+            External (internal) part of the RC-index (defaults to linearly
+            interpolating the hourly values given by the built-in RC-index
+            file).
+
+            .. note::
+
+                Use the external part of the RC-index for ``source='external'``
+                (default) and the internal part for ``source='internal'``.
 
         Returns
         -------
@@ -1443,12 +1540,12 @@ str, {'internal', 'external'}
                        self.breaks_delta['s11'][-1]])
 
         # ensure ndarray input
-        time = np.array(time, dtype=np.float)
+        time = np.asarray(time, dtype=float)
 
         if np.amin(time) < start or np.amax(time) > end:
             warnings.warn(
                 'Requested coefficients are outside of the '
-                f'modelled period from {start} to {end}. Doing linear '
+                f'model period from {start} to {end}. Doing linear '
                 'extrapolation in SM reference frame.')
 
         # load rotation matrix spectrum from file
@@ -1457,35 +1554,27 @@ str, {'internal', 'external'}
             frequency_spectrum['dipole'] == basicConfig['params.dipole']), \
             "SM rotation coefficients not compatible with the chosen dipole."
 
-        # load RC-index file: first hdf5 then dat-file format
-        try:
-            with h5py.File(basicConfig['file.RC_index'], 'r') as f_RC:
-                # check RC index time and input times
-                start = f_RC['time'][0]
-                end = f_RC['time'][-1]
-                # interpolate RC (linear) at input times: RC is callable
+        if rc is None:
+
+            # load RC-index file: first hdf5 then dat-file format
+            try:
+                with h5py.File(basicConfig['file.RC_index'], 'r') as f_RC:
+
+                    # create linear interpolant of the RC-index
+                    RC = sip.interp1d(f_RC['time'], f_RC['RC_' + source[0]],
+                                      kind='linear', bounds_error=True)
+
+            except OSError:
+                f_RC = du.load_RC_datfile(basicConfig['file.RC_index'])
+
+                # create linear interpolant of the RC-index
                 RC = sip.interp1d(f_RC['time'], f_RC['RC_' + source[0]],
-                                  kind='linear')
-        except OSError:  # dat file second
-            f_RC = du.load_RC_datfile(basicConfig['file.RC_index'])
-            start = f_RC['time'].iloc[0]
-            end = f_RC['time'].iloc[-1]
-            # interpolate RC (linear) at input times: RC is callable
-            RC = sip.interp1d(f_RC['time'], f_RC['RC_' + source[0]],
-                              kind='linear')
+                                  kind='linear', bounds_error=True)
 
-        if np.amin(time) < start:
-            raise ValueError(
-                'Insufficient RC time series. Input times must be between '
-                '{:.2f} and {:.2f}, but found {:.2f}.'.format(
-                    start, end, np.amin(time)))
+            rc = RC(time)  # interpolate RC-index
 
-        # check RC index time and inputs time
-        if np.amax(time) > end:
-            raise ValueError(
-                'Insufficient RC time series. Input times must be between '
-                '{:.2f} and {:.2f}, but found {:.2f}.'.format(
-                    start, end, np.amax(time)))
+        else:
+            rc = np.asarray(rc, dtype=float)  # use supplied index values
 
         # use piecewise polynomials to evaluate baseline correction in bins
         delta_q10 = sip.PPoly.construct_fast(
@@ -1510,14 +1599,11 @@ str, {'internal', 'external'}
             time, frequency, spectrum, scaled=scaled)
 
         if source == 'external':
-            coeffs_sm = np.empty(time.shape + (self.n_sm*(self.n_sm+2),))
+            coeffs_sm = np.empty(time.shape + (self.n_sm*(self.n_sm + 2),))
 
-            coeffs_sm[..., 0] = (RC(time)*self.coeffs_sm[0]
-                                 + delta_q10(time))
-            coeffs_sm[..., 1] = (RC(time)*self.coeffs_sm[1]
-                                 + delta_q11(time))
-            coeffs_sm[..., 2] = (RC(time)*self.coeffs_sm[2]
-                                 + delta_s11(time))
+            coeffs_sm[..., 0] = rc*self.coeffs_sm[0] + delta_q10(time)
+            coeffs_sm[..., 1] = rc*self.coeffs_sm[1] + delta_q11(time)
+            coeffs_sm[..., 2] = rc*self.coeffs_sm[2] + delta_s11(time)
             coeffs_sm[..., 3:] = self.coeffs_sm[3:]
 
             # rotate external SM coefficients to GEO reference
@@ -1527,7 +1613,6 @@ str, {'internal', 'external'}
             # unpack file: oscillations per day, complex spectrum
             frequency = frequency_spectrum['frequency_ind']
             spectrum = frequency_spectrum['spectrum_ind']
-            scaled = frequency_spectrum['scaled']
 
             # build rotation matrix for induced coefficients SM -> GEO
             rotate_gauss_ind = cu.synth_rotate_gauss(
@@ -1539,12 +1624,11 @@ str, {'internal', 'external'}
 
             coeffs_sm = np.empty(time.shape + (3,))
 
-            coeffs_sm[..., 0] = RC(time)*self.coeffs_sm[0]
-            coeffs_sm[..., 1] = RC(time)*self.coeffs_sm[1]
-            coeffs_sm[..., 2] = RC(time)*self.coeffs_sm[2]
+            coeffs_sm[..., 0] = rc*self.coeffs_sm[0]
+            coeffs_sm[..., 1] = rc*self.coeffs_sm[1]
+            coeffs_sm[..., 2] = rc*self.coeffs_sm[2]
 
-            coeffs_sm_ind = np.empty(
-                time.shape + (self.n_sm*(self.n_sm+2),))
+            coeffs_sm_ind = np.empty(time.shape + (self.n_sm*(self.n_sm + 2),))
 
             coeffs_sm_ind[..., 0] = delta_q10(time)
             coeffs_sm_ind[..., 1] = delta_q11(time)
@@ -1557,12 +1641,12 @@ str, {'internal', 'external'}
 
         else:
             raise ValueError(f'Unknown source "{source}". '
-                             'Use {external'', ''internal''}.')
+                             'Use one of {"external", "internal"}.')
 
         return coeffs[..., :nmax*(nmax+2)]
 
     def synth_values_sm(self, time, radius, theta, phi, *, nmax=None,
-                        source=None, grid=None):
+                        source=None, grid=None, rc_e=None, rc_i=None):
         """
         Compute SM magnetic field components.
 
@@ -1587,6 +1671,12 @@ str, {'internal', 'external'}
             If ``True``, field components are computed on a regular grid,
             which is created from ``theta`` and ``phi`` as their outer product
             (defaults to ``False``).
+        rc_e : ndarray, shape (...), optional
+            External part of the RC-index (defaults to linearly interpolating
+            the hourly values given by the built-in RC-index file).
+        rc_i : ndarray, shape (...), optional
+            Internal part of the RC-index (defaults to linearly interpolating
+            the hourly values given by the built-in RC-index file).
 
         Returns
         -------
@@ -1597,7 +1687,7 @@ str, {'internal', 'external'}
         --------
         >>> import chaosmagpy as cp
         >>> model = cp.CHAOS.from_mat('CHAOS-6-x7.mat')
-        >>> time = np.linspace(0., 10., num=2)
+        >>> time = np.array([0., 10.])
         >>> Br, Bt, Bp = model.synth_values_sm(time, 6371.2, 45., 0.)
         >>> Br
         array([-18.85890361, -13.99893523])
@@ -1608,10 +1698,11 @@ str, {'internal', 'external'}
         grid = False if grid is None else grid
 
         if source == 'all':
-            coeffs_ext = self.synth_coeffs_sm(time, nmax=nmax,
-                                              source='external')
-            coeffs_int = self.synth_coeffs_sm(time, nmax=nmax,
-                                              source='internal')
+
+            coeffs_ext = self.synth_coeffs_sm(
+                time, nmax=nmax, source='external', rc=rc_e)
+            coeffs_int = self.synth_coeffs_sm(
+                time, nmax=nmax, source='internal', rc=rc_i)
 
             B_radius_ext, B_theta_ext, B_phi_ext = mu.synth_values(
                 coeffs_ext, radius, theta, phi, source='external', grid=grid)
@@ -1623,7 +1714,12 @@ str, {'internal', 'external'}
             B_phi = B_phi_ext + B_phi_int
 
         elif source in ['external', 'internal']:
-            coeffs = self.synth_coeffs_sm(time, nmax=nmax, source=source)
+
+            # set the RC-index
+            rc = rc_e if source == 'external' else rc_i
+
+            coeffs = self.synth_coeffs_sm(
+                time, nmax=nmax, source=source, rc=rc)
             B_radius, B_theta, B_phi = mu.synth_values(
                 coeffs, radius, theta, phi, source=source, grid=grid)
 
@@ -1745,7 +1841,7 @@ str, {'internal', 'external'}
         --------
         >>> import chaosmagpy as cp
         >>> model = cp.CHAOS.from_mat('CHAOS-6-x7.mat')
-        >>> time = np.linspace(500., 600., num=2)
+        >>> time = np.array([500., 600.])
         >>> model.meta['satellites']  # check satellite names
         ('oersted', 'champ', 'sac_c', 'swarm_a', 'swarm_b', 'swarm_c')
 
@@ -1808,7 +1904,7 @@ str, {'internal', 'external'}
             order = self.model_tdep.order
 
             # compute times in mjd2000
-            times = np.array([], dtype=np.float)
+            times = np.array([], dtype=float)
             for start, end in zip(breaks[:-1], breaks[1:]):
                 step = (end - start)/(order-1)
                 times = np.append(times, np.arange(start, end, step))
@@ -1965,9 +2061,8 @@ str, {'internal', 'external'}
         filepath : str
             Path to mat-file containing the CHAOS model.
         name : str, optional
-            User defined name of the model. Defaults to ``'CHAOS-<version>'``,
-            where <version> is the default in
-            ``basicConfig['params.version']``.
+            User defined name of the model. Defaults to the filename without
+            the file extension.
         satellites : list of strings, optional
             List of satellite names whose Euler angles are stored in the
             mat-file. This is needed for correct referencing as this
@@ -2052,7 +2147,7 @@ def load_CHAOS_matfile(filepath, name=None, satellites=None):
     name : str, optional
         User defined name of the model. Defaults to the filename without the
         file extension.
-    satellites : list of strings
+    satellites : list of strings, optional
         List of satellite names whose Euler angles are stored in the mat-file.
         This is needed for correct referencing as this information is not
         given in the standard CHAOS mat-file format (defaults to
@@ -2204,7 +2299,7 @@ def load_CHAOS_matfile(filepath, name=None, satellites=None):
 
             angles = [model_euler[angle][num] for angle in [
                 'alpha', 'beta', 'gamma']]
-            euler = np.concatenate(angles, axis=-1).astype(np.float)
+            euler = np.concatenate(angles, axis=-1).astype(float)
 
             # first: order, second: number of intervals, third: 3 angles
             coeffs_euler[satellite] = np.expand_dims(euler, axis=0)
@@ -2331,44 +2426,50 @@ def load_CHAOS_shcfile(filepath, name=None, leap_year=None):
 
         nmin = params['nmin']
         nmax = params['nmax']
-        coeffs_static = np.zeros((nmax*(nmax+2),))
-        coeffs_static[int(nmin**2-1):] = coeffs  # pad zeros to coefficients
-        coeffs_static = coeffs_static.reshape((1, 1, -1))
-        model = CHAOS(breaks=np.array(time), coeffs_static=coeffs_static)
+
+        coeffs_pp = np.zeros((nmax * (nmax + 2),))
+        coeffs_pp[int(nmin**2 - 1):] = coeffs  # pad zeros to coefficients
+        coeffs_pp = coeffs_pp.reshape((1, 1, -1))
+
+        breaks = np.append(time, time)  # make a single piece
+
+        model = CHAOS(breaks=breaks, coeffs_static=coeffs_pp, name=name)
 
     else:  # time-dependent field
 
-        coeffs = np.transpose(coeffs)
         order = params['order']
         step = params['step']
         breaks = time[::step]
 
-        # interpolate with piecewise polynomial of given order
-        coeffs_pp = np.empty((order, time.size // step, coeffs.shape[-1]))
-        for m, left_break in enumerate(breaks[:-1]):
-            left = m * step  # time index of left_break
-            x = time[left:left+order] - left_break
-            c = np.linalg.solve(np.vander(x, order), coeffs[left:left+order])
+        end = (time.size // step) * step  # to discard extrapolation sites
 
-            for k in range(order):
-                coeffs_pp[k, m] = c[k]
+        knots = mu.augment_breaks(breaks, order)
+        spl = sip.make_lsq_spline(time[:end], coeffs[:, :end].T,
+                                  knots, order - 1)
+        coeffs_out = spl.c.copy()
 
-        model = CHAOS(breaks=breaks,
-                      order=order,
-                      coeffs_tdep=coeffs_pp,
-                      name=name)
+        # convert B-spline basis to PPoly
+        coeffs_pp, _ = mu.pp_from_bspline(coeffs_out, knots, order)
+
+        model = CHAOS(
+            breaks=breaks,
+            order=order,
+            coeffs_tdep=coeffs_pp,
+            name=name
+        )
 
     return model
 
 
 def load_CovObs_txtfile(filepath, name=None):
     """
-    Load model parameter file of the COV-OBS model.
+    Load the ensemble mean of the internal model from the COV-OBS
+    txt-file in spline format.
 
     Parameters
     ----------
     filepath : str
-        Path to txt-file (not part of ChaosMagPy).
+        Path to spline-formatted txt-file (not part of ChaosMagPy).
     name : str, optional
         User defined name of the model. Defaults to the filename without the
         file extension.
@@ -2389,9 +2490,9 @@ def load_CovObs_txtfile(filepath, name=None):
 
     Examples
     --------
-    Load the model and plot the degree-1 secular variation. Here, the
-    model parameter file, e.g. "COV-OBS.x2-int", is in the current working
-    directory.
+    Load the ensemble mean internal model and plot the degree-1 secular
+    variation. Here, the model parameter file, e.g. "COV-OBS.x2-int", is in
+    the current working directory.
 
     .. code-block:: python
 
@@ -2435,20 +2536,20 @@ def load_CovObs_txtfile(filepath, name=None):
     # convert decimal year to modified Julian date (using 365.25 days/year)
     breaks = du.dyear_to_mjd(tmp[3:], leap_year=False)
 
-    # add endpoint multiplicity to "trick" scipy's BSpline routine
+    # add endpoint multiplicity to conform with scipy's BSpline routine
     knots = mu.augment_breaks(breaks, order)
 
     data = np.fromstring(' '.join(lines[2:]), sep=' ')
 
     # add zeros at endpoints to match manually extended knots
-    coeffs = np.zeros((knots.size - order, nmax*(nmax+2)))
+    coeffs = np.zeros((knots.size - order, nmax * (nmax + 2)))
 
     # insert actual coefficients, endpoint coefficients are now zero
     coeffs[degree:-degree, :] = data.reshape(
-        (breaks.size - order, nmax*(nmax+2)))
+        (breaks.size - order, nmax * (nmax + 2)))
 
     return BaseModel.from_bspline(name, knots, coeffs, order,
-                                  source='internal', meta=None)
+                                  source='internal')
 
 
 def load_gufm1_txtfile(filepath, name=None):
@@ -2528,11 +2629,11 @@ def load_gufm1_txtfile(filepath, name=None):
     knots = mu.augment_breaks(breaks, order)
 
     # add zeros at endpoints to match manually extended knots
-    coeffs = np.zeros((knots.size - order, nmax*(nmax + 2)))
+    coeffs = np.zeros((knots.size - order, nmax * (nmax + 2)))
 
     # insert actual coefficients, endpoint coefficients are now zero
     coeffs[degree:-degree, :] = data[(nbreaks + 2):].reshape(
-        (breaks.size - order, nmax*(nmax + 2)))
+        (breaks.size - order, nmax * (nmax + 2)))
 
     return BaseModel.from_bspline(name, knots, coeffs, order,
-                                  source='internal', meta=None)
+                                  source='internal')
